import { LocalizationProvider } from "@mui/x-date-pickers";
import { AdapterDayjs } from "@mui/x-date-pickers/AdapterDayjs";
import { DatePicker } from "@mui/x-date-pickers/DatePicker";
import dayjs from "dayjs";
import "dayjs/locale/fr";
import { fmtUnixDate } from "../../utils/time_utils";
import { PropEdit } from "./PropEdit";

export function PropDateInput(p: {
  editable: boolean;
  label: string;
  value: number | undefined;
  onChange: (v: number | undefined) => void;
  lastSecOfDay?: boolean;
}): React.ReactElement {
  let shiftV = p.value;
  if (shiftV && p.lastSecOfDay) {
    const d = new Date(shiftV * 1000);
    if (d.getHours() === 0) {
      shiftV -= 1;
    }
  }

  if (!p.editable) {
    if (!shiftV) return <></>;

    return (
      <PropEdit editable={false} label={p.label} value={fmtUnixDate(shiftV)} />
    );
  }

  const value = dayjs(
    shiftV && p.value! > 0 ? new Date(shiftV * 1000) : undefined
  );

  return (
    <div style={{ margin: "10px auto" }}>
      <LocalizationProvider dateAdapter={AdapterDayjs} adapterLocale="fr">
        <DatePicker
          label={p.label}
          value={value}
          onChange={(v) => {
            if (v && p.lastSecOfDay) {
              v.set("hours", 23);
              v.set("minutes", 59);
              v.set("seconds", 59);
            }
            p.onChange?.(v ? v.unix() : undefined);
          }}
        />
      </LocalizationProvider>
    </div>
  );
}
